==> tdm_2.0.0.tar.gz: tdm/R/all.Theirss.R <==
all.Theirss<-function(){
     cat("\n")                                                                      
     cat("----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--      \n")
     note_for_Theirss_input()
     cat("----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                    
     TheirSSpar<-edit(TheirSSpar)                                                                                                                     
     TheirSSpar<-ycheck(TheirSSpar)   
     cat("\n")                                                                                                                 
     Their.ss(TheirSSpar[9,2],TheirSSpar[7,2],TheirSSpar[8,2],TheirSSpar[6,2],TheirSSpar[3,2],TheirSSpar[2,2],TheirSSpar[5,2],TheirSSpar[1,2],TheirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------\n")
     cat("    --Theophylline IR output data information--                  \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     Their.more()                      
}

==> tdm_2.2.6.tar.gz: tdm/R/all.Theirss.R <==
all.Theirss<-function(){
     cat("\n")                                                                      
     cat("----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--      \n")
     note_for_Theirss_input()
     cat("----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                    
     TheirSSpar<-edit(TheirSSpar)                                                                                                                     
##     TheirSSpar<-ycheck(TheirSSpar)   
     cat("\n")                                                                                                                 
     Their.ss(TheirSSpar[9,2],TheirSSpar[7,2],TheirSSpar[8,2],TheirSSpar[6,2],TheirSSpar[3,2],TheirSSpar[2,2],TheirSSpar[5,2],TheirSSpar[1,2],TheirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------\n")
     cat("    --Theophylline IR output data information--                  \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     Their.more()                      
}
